Python finite state machine package
===================================

|pypi| |ci| |coverage| |docs|

Simple finite state machine implementation written in Python

Online documentation is at https://fstatemachine.readthedocs.io/.

Bugs can be reported to https://github.com/yakimka/fstatemachine. The code can also
be found there.

.. |ci| image:: https://github.com/yakimka/fstatemachine/workflows/Run%20linters,%20tests%20and%20upload%20to%20pypi/badge.svg
    :target: https://github.com/yakimka/fstatemachine/actions
.. |coverage| image:: https://codecov.io/gh/yakimka/fstatemachine/branch/master/graph/badge.svg?token=5YNW56XJQT
    :target: https://codecov.io/gh/yakimka/fstatemachine
.. |docs| image:: https://readthedocs.org/projects/fstatemachine/badge/?version=latest
    :target: https://fstatemachine.readthedocs.io/en/latest/?badge=latest
    :alt: Documentation Status
.. |pypi| image:: https://img.shields.io/pypi/v/fstatemachine.svg
   :target: https://pypi.org/project/fstatemachine/
   :alt: fstatemachine on PyPI
